@@ -1,5 +1,7 @@
 var NAVTREEINDEX5 =
 {
+"index.html#restclient":[6,0,15],
+"index.html#restservice":[6,1,10],
 "index.html#rpcversusdoclit":[9,0],
 "index.html#rules":[9],
 "index.html#safety":[25,13],
@@ -247,7 +249,5 @@ var NAVTREEINDEX5 =
 "structsoap.html#ab85f5d42702963d13ea540bd9876e6d2":[27,5,0,47],
 "structsoap.html#ab8f356cfb0a1ba87c26cb0ae4c9ee713":[27,5,0,96],
 "structsoap.html#ab9d0aab0f89e2109ba02ca460c219541":[27,5,0,156],
-"structsoap.html#abda4ccd0d64f76eb57145cc4890c87b2":[27,5,0,9],
-"structsoap.html#ac091dfe4e01b6a082d916c381e7006ba":[27,5,0,95],
-"structsoap.html#ac172bd9019afeebb3635b3a9f72a9101":[27,5,0,131]
+"structsoap.html#abda4ccd0d64f76eb57145cc4890c87b2":[27,5,0,9]
 };
